@@ -44,6 +44,12 @@ import math
 import pandas as pd
 import napari
 import glob
+from qtpy.QtCore import Qt
+from qtpy.QtWidgets import QComboBox, QPushButton, QSlider
+
+
+Boxname = 'ImageIDBox'
+
 
 class SegCorrect(object):
 
@@ -117,11 +123,7 @@ class SegCorrect(object):
                                                             self.viewer.layers.remove(layer)
 
 
-                        self.image = daskread(image_toread)
-                        if len(self.image.shape) > 3:
-                            self.image = self.image[0,:]
-
-                        self.image = imread(image_to_read)
+                        self.image = imread(image_toread)
                         self.segimage =  imread(seg_image_toread)
                         
                         self.viewer.add_image(self.image, name='Image'+imagename)
